@@ -1,4 +1,4 @@
-__version__ = "1.0.4"
+__version__ = "1.1.0"
 
 from sys import stdout
 from typing import Union
@@ -21,11 +21,11 @@ def rprint(
     """
     stdout.write auto-reset wrapper
     """
-    stdout.write(foreground + style + background + text + Style.RESET + "\n")
+    stdout.write(foreground + style + background + text + Style.RESET_ALL + "\n")
 
 
 def reset() -> None:
     """
     function reset
     """
-    stdout.write(Style.RESET.value)
+    stdout.write(Style.RESET_ALL.value)
